@@ -3,7 +3,7 @@
 
 """An unofficial Farsight Security DNSDB client"""
 
-from __future__ import print_function, unicode_literals
+from __future__ import print_function
 
 import os
 import logging
@@ -34,7 +34,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License."""
 
-__version__ = "1.1.1"
+__version__ = "1.2.0"
 
 locale.setlocale(locale.LC_ALL, '')
 
@@ -66,7 +66,7 @@ def _timestamp_to_iso8601(dt):
 
     Returns:
 
-    str: a timestamp formatted ``YYYY-MM-DD HH:MM:SS``
+    str: a timestamp in ISO 5601 format
     """
 
     if type(dt) == int:
@@ -261,10 +261,15 @@ def _dnsdb_result_to_text(result):
         ))
 
     if 'rdata' in result:
-        for rdata in result['rdata']:
+        if type(result["rdata"]) == list:
+            for rdata in result['rdata']:
+                s += '{0} IN {1} {2}\n'.format(result['rrname'],
+                                               result['rrtype'],
+                                               rdata)
+        else:
             s += '{0} IN {1} {2}\n'.format(result['rrname'],
                                            result['rrtype'],
-                                           rdata)
+                                           result["rdata"])
 
     return s
 
@@ -460,19 +465,19 @@ class DNSDBAPI(object):
         if first_seen_before is not None:
             first_seen_before = _datetime_to_timestamp(
                 dateparser.parse(first_seen_before))
-            params["first_seen_before"] = first_seen_before
+            params["time_first_before"] = first_seen_before
         if first_seen_after is not None:
             first_seen_after = _datetime_to_timestamp(
                 dateparser.parse(first_seen_after))
-            params["first_seen_after"] = first_seen_after
+            params["time_first_after"] = first_seen_after
         if last_seen_before is not None:
             last_seen_before = _datetime_to_timestamp(
                 dateparser.parse(last_seen_before))
-            params["last_seen_before"] = last_seen_before
+            params["time_last_before"] = last_seen_before
         if last_seen_after is not None:
             last_seen_after = _datetime_to_timestamp(
                 dateparser.parse(last_seen_after))
-            params["last_seen_after"] = last_seen_after
+            params["time_last_after"] = last_seen_after
         try:
             return self._get(endpoint, params=params,
                              sort_by=sort_by, reverse=reverse)
@@ -516,19 +521,19 @@ class DNSDBAPI(object):
         if first_seen_before is not None:
             first_seen_before = _datetime_to_timestamp(
                 dateparser.parse(first_seen_before))
-            params["first_seen_before"] = first_seen_before
+            params["time_first_before"] = first_seen_before
         if first_seen_after is not None:
             first_seen_after = _datetime_to_timestamp(
                 dateparser.parse(first_seen_after))
-            params["first_seen_after"] = first_seen_after
+            params["time_first_after"] = first_seen_after
         if last_seen_before is not None:
             last_seen_before = _datetime_to_timestamp(
                 dateparser.parse(last_seen_before))
-            params["last_seen_before"] = last_seen_before
+            params["time_last_before"] = last_seen_before
         if last_seen_after is not None:
             last_seen_after = _datetime_to_timestamp(
                 dateparser.parse(last_seen_after))
-            params["last_seen_after"] = last_seen_after
+            params["time_last_after"] = last_seen_after
 
         try:
             return self._get(endpoint, params=params,
@@ -575,10 +580,6 @@ def _get_quotas(ctx):
                                      "type.",
               default="ANY", show_default=True)
 @click.option("-b", "--bailiwick", help="Filter results by DNS bailiwick.")
-@click.option("--first-seen-before",
-              help="Only show results first seen before this date.")
-@click.option("--first-seen-after",
-              help="Only show results first seen after this date.")
 @click.option("--first-seen-before",
               help="Only show results first seen before this date.")
 @click.option("--first-seen-after",
@@ -657,10 +658,6 @@ def _forward_lookup(ctx, owner_name, rrtype="ANY", bailiwick=None,
               help="Only show results first seen before this date.")
 @click.option("--first-seen-after",
               help="Only show results first seen after this date.")
-@click.option("--first-seen-before",
-              help="Only show results first seen before this date.")
-@click.option("--first-seen-after",
-              help="Only show results first seen after this date.")
 @click.option("--last-seen-before",
               help="Only show results last seen before this date.")
 @click.option("--last-seen-after",
@@ -701,7 +698,7 @@ def _inverse_lookup(ctx, query_type, value, rrtype="ANY",
             sort_by=sort_by,
             reverse=reverse
         )
-        if output_paths is None:
+        if len(output_paths) == 0:
             if _format == "json":
                 print(dnsdb_results_to_json(results))
             elif _format == "csv":
